from setuptools import setup

setup(
        name="fc_bigdataysk567",#项目名
        version = "1.0",    #版本号
        py_modules=["fc_mkdxd_bigdata"],#生成模块
        author="大数据3",       #作者
        author_email="2294090178@qq.com",#邮箱
        description="毛坤铎"    #项目信息
)